Module headless

Module headless 

Functions

from_headless_bytes
Convenience decode from bytes for headless payload.
read_headless
Alias kept for API ergonomics in packet codec code.
read_headless_by_id
Reads a headless value when only the type id byte is available.
read_headless_by_id_with_config
read_headless_by_id_with_limits
read_headless_prefixed
Reads a value where a type id byte is prefixed before headless payload.
read_headless_prefixed_with_config
read_headless_prefixed_with_limits
read_headless_with_config
read_headless_with_limits
read_value
Reads a headless NBT value payload using an externally known tag type.
read_value_with_config
read_value_with_limits
to_headless_bytes
Convenience encode to bytes for headless payload.
write_headless
Alias kept for API ergonomics in packet codec code.
write_headless_prefixed
Writes a value as type_id + payload without root-name.
write_value
Writes a headless NBT value payload (no tag id, no name).