Functions
- from_
headless_ bytes - Convenience decode from bytes for headless payload.
- read_
headless - Alias kept for API ergonomics in packet codec code.
- read_
headless_ by_ id - Reads a headless value when only the type id byte is available.
- read_
headless_ by_ id_ with_ config - read_
headless_ by_ id_ with_ limits - read_
headless_ prefixed - Reads a value where a type id byte is prefixed before headless payload.
- read_
headless_ prefixed_ with_ config - read_
headless_ prefixed_ with_ limits - read_
headless_ with_ config - read_
headless_ with_ limits - read_
value - Reads a headless NBT value payload using an externally known tag type.
- read_
value_ with_ config - read_
value_ with_ limits - to_
headless_ bytes - Convenience encode to bytes for headless payload.
- write_
headless - Alias kept for API ergonomics in packet codec code.
- write_
headless_ prefixed - Writes a value as
type_id + payloadwithout root-name. - write_
value - Writes a headless NBT value payload (no tag id, no name).