pub fn read_value<E: Encoding, R: Read>(
reader: &mut R,
tag_type: TagType,
) -> Result<Tag>Expand description
Reads a headless NBT value payload using an externally known tag type.
This is the canonical low-level API for protocol fields where the type is provided by surrounding packet metadata.